@@ -3,24 +3,33 @@ from textwrap import wrap
 from typing import Any, OrderedDict, Tuple
 
 import yaml
+from semver.version import Version
 
 from ops2deb.exceptions import Ops2debFormatterError
 from ops2deb.parser import (
     Blueprint,
     ConfigurationFile,
+    Resources,
     get_default_lockfile_path,
-    load_configuration,
 )
 from ops2deb.utils import PrettyYAMLDumper
 
 
 def sort_blueprints(blueprints: list[OrderedDict[str, Any]]) -> list[dict[str, Any]]:
-    def key(blueprint: dict[str, Any]) -> Tuple[str, str, int]:
+    def key(blueprint: dict[str, Any]) -> Tuple[str, Version, int]:
         try:
-            version = blueprint["matrix"]["versions"][-1]
+            version_str = blueprint["matrix"]["versions"][-1]
         except KeyError:
-            version = blueprint["version"]
-        return blueprint["name"], version, blueprint.get("revision", "1")
+            version_str = blueprint["version"]
+        version: Version = Version(0, 0, 0)
+        if Version.isvalid(version_str):
+            version = Version.parse(version_str)
+        revision_str = blueprint.get("revision", "1")
+        try:
+            revision = int(revision_str)
+        except ValueError:
+            revision = 1
+        return blueprint["name"], version, revision
 
     return sorted(blueprints, key=key)
 
@@ -89,9 +98,9 @@ def format_configuration_file(configuration: ConfigurationFile) -> bool:
     return formatted_configuration_content != original_configuration_content
 
 
-def format_all(search_glob: str) -> None:
+def format_all(resources: Resources) -> None:
     formatted_configuration_files: list[str] = []
-    for configuration in load_configuration(search_glob).configuration_files:
+    for configuration in resources.configuration_files:
         if format_configuration_file(configuration) is True:
             formatted_configuration_files.append(str(configuration.path))
     if formatted_configuration_files:
